@@ -5,15 +5,15 @@ from autoarray.dataset.imaging.dataset import Imaging
 from autoarray.dataset.interferometer.dataset import (
     Interferometer,
 )
+from autoarray.dataset.grids import GridsInterface
 from autoarray.dataset.dataset_model import DatasetModel
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
+from autoarray.mask.derive.zoom_2d import Zoom2D
 from autoarray.operators.convolver import Convolver
-from autoarray.operators.over_sampling.uniform import OverSamplingUniform  # noqa
-from autoarray.operators.over_sampling.uniform import OverSamplerUniform  # noqa
-from autoarray.operators.over_sampling.iterate import OverSamplingIterate
-from autoarray.operators.over_sampling.iterate import OverSamplerIterate
+from autoarray.operators.over_sampling.over_sampler import OverSampler  # noqa
 from autoarray.inversion.inversion.dataset_interface import DatasetInterface
+from autoarray.inversion.inversion.mapper_valued import MapperValued
 from autoarray.inversion.pixelization import image_mesh
 from autoarray.inversion.pixelization import mesh
 from autoarray.inversion import regularization as reg
@@ -26,25 +26,30 @@ from autoarray.inversion.inversion.factory import inversion_from as Inversion
 from autoarray.inversion.pixelization.mappers.abstract import AbstractMapper
 from autoarray.inversion.pixelization.mappers.mapper_grids import MapperGrids
 from autoarray.inversion.pixelization.mappers.factory import mapper_from as Mapper
+from autoarray.inversion.pixelization.border_relocator import BorderRelocator
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
 from autoarray.structures.arrays.uniform_1d import Array1D
 from autoarray.structures.arrays.uniform_2d import Array2D
+from autoarray.structures.arrays.rgb import Array2DRGB
 from autoarray.structures.arrays.irregular import ArrayIrregular
 from autoarray.structures.grids.uniform_1d import Grid1D
 from autoarray.structures.grids.uniform_2d import Grid2D
 from autoarray.structures.grids.irregular_2d import Grid2DIrregular
-from autoarray.structures.grids.irregular_2d import Grid2DIrregularUniform
-from autoarray.operators.over_sampling.iterate import OverSamplingIterate
 from autoarray.structures.mesh.rectangular_2d import Mesh2DRectangular
 from autoarray.structures.mesh.voronoi_2d import Mesh2DVoronoi
 from autoarray.structures.mesh.delaunay_2d import Mesh2DDelaunay
+from autoarray.structures.triangles.shape import Circle
+from autoarray.structures.triangles.shape import Triangle
+from autoarray.structures.triangles.shape import Square
+from autoarray.structures.triangles.shape import Polygon
 from autoarray.structures.vectors.uniform import VectorYX2D
 from autoarray.structures.vectors.irregular import VectorYX2DIrregular
 from autoarray.structures.arrays.kernel_2d import Kernel2D
 from autoarray.structures.visibilities import Visibilities
 from autoarray.structures.visibilities import VisibilitiesNoiseMap
 
+
 from autogalaxy import cosmology as cosmo
 from autogalaxy.analysis.adapt_images.adapt_images import AdaptImages
 from autogalaxy.analysis.adapt_images.adapt_image_maker import AdaptImageMaker
@@ -53,8 +58,6 @@ from autogalaxy.gui.scribbler import Scribbler
 from autogalaxy.galaxy.galaxy import Galaxy
 from autogalaxy.galaxy.galaxies import Galaxies
 from autogalaxy.galaxy.redshift import Redshift
-from autogalaxy.analysis.clump_model import ClumpModel
-from autogalaxy.analysis.clump_model import ClumpModelDisabled
 
 from autogalaxy.quantity.dataset_quantity import DatasetQuantity
 from autogalaxy.profiles.geometry_profiles import EllProfile
@@ -62,6 +65,7 @@ from autogalaxy.profiles import (
     point_sources as ps,
     mass as mp,
     light_and_mass_profiles as lmp,
+    light_linear_and_mass_profiles as lmp_linear,
     scaling_relations as sr,
 )
 from autogalaxy.profiles.light.abstract import LightProfile
@@ -69,10 +73,11 @@ from autogalaxy.profiles.light import standard as lp
 from autogalaxy.profiles.light import snr as lp_snr
 from autogalaxy.profiles.light import linear as lp_linear
 from autogalaxy.profiles.light import operated as lp_operated
-from autogalaxy.profiles.light import basis as lp_basis
+from autogalaxy.profiles import basis as lp_basis
 from autogalaxy.profiles.light import (
     linear_operated as lp_linear_operated,
 )
+from autogalaxy.profiles.light.linear import LightProfileLinearObjFuncList
 from autogalaxy.operate.image import OperateImage
 from autogalaxy.operate.deflections import OperateDeflections
 from autogalaxy.quantity.dataset_quantity import DatasetQuantity
@@ -82,26 +87,30 @@ from . import plot
 from . import aggregator as agg
 from .lens import subhalo
 from .lens.tracer import Tracer
+from .lens.sensitivity import SubhaloSensitivityResult
 from .lens.to_inversion import TracerToInversion
 from .analysis.positions import PositionsLHResample
 from .analysis.positions import PositionsLHPenalty
-from .analysis.preloads import Preloads
 from .imaging.simulator import SimulatorImaging
 from .imaging.fit_imaging import FitImaging
 from .imaging.model.analysis import AnalysisImaging
+from .imaging.model.visualizer import VisualizerImaging
 from .interferometer.simulator import SimulatorInterferometer
 from .interferometer.fit_interferometer import FitInterferometer
 from .interferometer.model.analysis import AnalysisInterferometer
-from .point.point_dataset import PointDataset
-from .point.point_dataset import PointDict
-from .point.fit_point.point_dict import FitPointDict
-from .point.fit_point.point_dataset import FitPointDataset
-from .point.fit_point.fluxes import FitFluxes
-from .point.fit_point.positions_image import FitPositionsImage
-from .point.fit_point.positions_source import FitPositionsSource
-from .point.fit_point.max_separation import FitPositionsSourceMaxSeparation
+from .interferometer.model.visualizer import VisualizerInterferometer
+from .point.dataset import PointDataset
+from .point.fit.dataset import FitPointDataset
+from .point.fit.fluxes import FitFluxes
+from .point.fit.positions.image.abstract import AbstractFitPositionsImagePair
+from .point.fit.positions.image.pair import FitPositionsImagePair
+from .point.fit.positions.image.pair_all import FitPositionsImagePairAll
+from .point.fit.positions.image.pair_repeat import FitPositionsImagePairRepeat
+from .point.fit.positions.source.separations import FitPositionsSource
+from .point.max_separation import SourceMaxSeparation
 from .point.model.analysis import AnalysisPoint
-from .point.point_solver import PointSolver
+from .point.solver import PointSolver
+from .point.solver.shape_solver import ShapeSolver
 from .quantity.fit_quantity import FitQuantity
 from .quantity.model.analysis import AnalysisQuantity
 from . import exc
@@ -109,7 +118,12 @@ from . import mock as m
 from . import util
 
 from autoconf import conf
+from autoconf.fitsable import ndarray_via_hdu_from
+from autoconf.fitsable import ndarray_via_fits_from
+from autoconf.fitsable import header_obj_from
+from autoconf.fitsable import output_to_fits
+from autoconf.fitsable import hdu_list_for_output_from
 
 conf.instance.register(__file__)
 
-__version__ = "2024.5.16.0"
+__version__ = "2025.5.9.48"
