@@ -13,7 +13,9 @@ import autogalaxy as ag
 from autogalaxy.analysis.analysis.dataset import AnalysisDataset
 
 from autolens.lens.tracer import Tracer
-from autolens.point.fit_point.max_separation import FitPositionsSourceMaxSeparation
+from autolens.point.max_separation import (
+    SourceMaxSeparation,
+)
 
 from autolens import exc
 
@@ -59,7 +61,7 @@ class AbstractPositionsLH:
 
     def output_positions_info(self, output_path: str, tracer: Tracer):
         """
-        Outputs a `positions.info` file which summarizes the positions penalty term for a model fit, including:
+        Outputs a `positions.info` file which summarises the positions penalty term for a model fit, including:
 
         - The arc second coordinates of the lensed source multiple images used for the model-fit.
         - The radial distance of these coordinates from (0.0, 0.0).
@@ -75,11 +77,11 @@ class AbstractPositionsLH:
         -------
 
         """
-        positions_fit = FitPositionsSourceMaxSeparation(
-            positions=self.positions, noise_map=None, tracer=tracer
+        positions_fit = SourceMaxSeparation(
+            data=self.positions, noise_map=None, tracer=tracer
         )
 
-        distances = positions_fit.positions.distances_to_coordinate_from(
+        distances = positions_fit.data.distances_to_coordinate_from(
             coordinate=(0.0, 0.0)
         )
 
@@ -139,8 +141,8 @@ class PositionsLHResample(AbstractPositionsLH):
         if not tracer.has(cls=ag.mp.MassProfile) or len(tracer.planes) == 1:
             return
 
-        positions_fit = FitPositionsSourceMaxSeparation(
-            positions=self.positions, noise_map=None, tracer=tracer
+        positions_fit = SourceMaxSeparation(
+            data=self.positions, noise_map=None, tracer=tracer
         )
 
         if not positions_fit.max_separation_within_threshold(self.threshold):
@@ -262,8 +264,8 @@ class PositionsLHPenalty(AbstractPositionsLH):
         if not tracer.has(cls=ag.mp.MassProfile) or len(tracer.planes) == 1:
             return
 
-        positions_fit = FitPositionsSourceMaxSeparation(
-            positions=self.positions, noise_map=None, tracer=tracer
+        positions_fit = SourceMaxSeparation(
+            data=self.positions, noise_map=None, tracer=tracer
         )
 
         if not positions_fit.max_separation_within_threshold(self.threshold):
