@@ -1,3 +1,4 @@
+import logging
 import os
 import numpy as np
 from typing import Optional, Union
@@ -9,9 +10,13 @@ from autogalaxy.analysis.result import ResultDataset as AgResultDataset
 
 from autolens.analysis.positions import PositionsLHResample
 from autolens.analysis.positions import PositionsLHPenalty
-from autolens.point.fit_point.max_separation import FitPositionsSourceMaxSeparation
+from autolens.point.max_separation import (
+    SourceMaxSeparation,
+)
 from autolens.lens.tracer import Tracer
-from autolens.point.point_solver import PointSolver
+from autolens.point.solver import PointSolver
+
+logger = logging.getLogger(__name__)
 
 
 class Result(AgResultDataset):
@@ -42,8 +47,8 @@ class Result(AgResultDataset):
         -------
 
         """
-        positions_fits = FitPositionsSourceMaxSeparation(
-            positions=self.analysis.positions_likelihood.positions,
+        positions_fits = SourceMaxSeparation(
+            data=self.analysis.positions_likelihood.positions,
             noise_map=None,
             tracer=self.max_log_likelihood_tracer,
         )
@@ -89,17 +94,86 @@ class Result(AgResultDataset):
 
         grid = self.analysis.dataset.mask.derive_grid.all_false
 
-        solver = PointSolver(
-            grid=grid, pixel_scale_precision=0.001, distance_to_mass_profile_centre=0.05
+        solver = PointSolver.for_grid(
+            grid=grid,
+            pixel_scale_precision=0.001,
         )
 
         multiple_images = solver.solve(
-            lensing_obj=self.max_log_likelihood_tracer,
+            tracer=self.max_log_likelihood_tracer,
             source_plane_coordinate=self.source_plane_centre.in_list[0],
         )
 
+        if multiple_images.shape[0] == 1:
+            return self.image_plane_multiple_image_positions_for_single_image_from()
+
         return aa.Grid2DIrregular(values=multiple_images)
 
+    def image_plane_multiple_image_positions_for_single_image_from(
+        self, increments: int = 20
+    ) -> aa.Grid2DIrregular:
+        """
+        If the standard point solver only locates one multiple image, finds one or more additional images, which are
+        not technically multiple image in the point source regime, but are close enough to it they can be used
+        in a position threshold likelihood.
+
+        This is performed by incrementally moving the source-plane centre's coordinates towards the centre of the
+        source-plane at (0.0", 0.0"). This ensures that the centre will eventually go inside the caustic, where
+        multiple images are formed.
+
+        To move the source-plane centre, the original source-plane centre is multiplied by a factor that decreases
+        from 1.0 to 0.0 in increments of 1/increments. For example, if the source-plane centre is (1.0", -0.5") and
+        the `factor` is 0.5, the input source-plane centre is (0.5", -0.25").
+
+        The multiple images are always computed for the same mass model, thus they will always be valid multiple images
+        for the model being fitted, but as the factor decrease the multiple images may move furhter from their observed
+        positions.
+
+        Parameters
+        ----------
+        increments
+            The number of increments the source-plane centre is moved to compute multiple images.
+        """
+
+        logger.info(
+            """
+        Could not find multiple images for maximum likelihood lens model.
+        
+        Incrementally moving source centre inwards towards centre of source-plane until caustic crossing occurs
+        and multiple images are formed.        
+        """
+        )
+
+        grid = self.analysis.dataset.mask.derive_grid.all_false
+
+        centre = self.source_plane_centre.in_list[0]
+
+        solver = PointSolver.for_grid(
+            grid=grid,
+            pixel_scale_precision=0.001,
+        )
+
+        for i in range(1, increments):
+            factor = 1.0 - (1.0 * (i / increments))
+
+            multiple_images = solver.solve(
+                tracer=self.max_log_likelihood_tracer,
+                source_plane_coordinate=(centre[0] * factor, centre[1] * factor),
+            )
+
+            if multiple_images.shape[0] > 1:
+                return aa.Grid2DIrregular(values=multiple_images)
+
+        logger.info(
+            """
+        Could not find multiple images for maximum likelihood lens model, even after incrementally moving the source
+        centre inwards to the centre of the source-plane.
+
+        Set the multiple image postiions to two images at (1.0", 1.0") so code continues to run.
+        """
+        )
+        return aa.Grid2DIrregular(values=[(1.0, 1.0), (1.0, 1.0)])
+
     def positions_threshold_from(
         self,
         factor=1.0,
@@ -145,8 +219,8 @@ class Result(AgResultDataset):
 
         tracer = Tracer(galaxies=self.max_log_likelihood_galaxies)
 
-        positions_fits = FitPositionsSourceMaxSeparation(
-            positions=positions, noise_map=None, tracer=tracer
+        positions_fits = SourceMaxSeparation(
+            data=positions, noise_map=None, tracer=tracer
         )
 
         threshold = factor * np.max(
@@ -165,7 +239,47 @@ class Result(AgResultDataset):
         minimum_threshold=None,
         use_resample=False,
         positions: Optional[aa.Grid2DIrregular] = None,
+        mass_centre_radial_distance_min: float = None,
     ) -> Union[PositionsLHPenalty, PositionsLHResample]:
+        """
+        Returns a `PositionsLH` object from the result of a lens model-fit, where the maximum log likelihood mass
+        and source models are used to determine the multiple image positions in the image-plane and source-plane
+        and ray-trace them to the source-plane to determine the threshold.
+
+        In chained fits, for example the SLaM pipelines, this means that a simple initial fit (e.g. SIE mass model,
+        parametric source) can be used to determine the multiple image positions and threshold for a more complex
+        subsequent fit (e.g. power-law mass model, pixelized source).
+
+        The mass model central image is removed from the solution, as this is rarely physically observed and therefore
+        should not be included in the likelihood penalty or resampling. It is removed by setting a positive
+        magnification threshold in the `PointSolver`. For strange lens models the central image may still be
+        solved for, in which case the `mass_centre_radial_distance_min` parameter can be used to remove it.
+
+        Parameters
+        ----------
+        factor
+            The value the computed threshold is multiplied by to make the position threshold larger or smaller than the
+            maximum log likelihood model's threshold.
+        minimum_threshold
+            The output threshold is rounded up to this value if it is below it, to avoid extremely small threshold
+            values.
+        use_resample
+            If `False` the `PositionsLH` object is created using the `PositionsLHPenalty` class, which uses the
+            threshold to apply a penalty term to the likelihood. If `True` the `PositionsLH` object is created using
+            the `PositionsLHResample` class, which resamples the positions to the threshold.
+        positions
+            If input, these positions are used instead of the computed multiple image positions from the lens mass
+            model.
+        mass_centre_radial_distance_min
+            The minimum radial distance from the mass model centre that a multiple image position must be to be
+            included in the likelihood penalty or resampling. If `None` all positions are used. This is an additional
+            method to remove central images that may make it through the point solver's magnification threshold.
+
+        Returns
+        -------
+        The `PositionsLH` object used to apply a likelihood penalty or resample the positions.
+        """
+
         if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
             return None
 
@@ -174,6 +288,18 @@ class Result(AgResultDataset):
             if positions is None
             else positions
         )
+
+        if mass_centre_radial_distance_min is not None:
+            mass_centre = self.max_log_likelihood_tracer.extract_attribute(
+                cls=ag.mp.MassProfile, attr_name="centre"
+            )
+
+            distances = positions.distances_to_coordinate_from(
+                coordinate=mass_centre[0]
+            )
+
+            positions = positions[distances > mass_centre_radial_distance_min]
+
         threshold = self.positions_threshold_from(
             factor=factor, minimum_threshold=minimum_threshold, positions=positions
         )
@@ -232,6 +358,12 @@ class ResultDataset(Result):
         """
         if self.max_log_likelihood_fit.inversion is not None:
             if self.max_log_likelihood_fit.inversion.has(cls=aa.AbstractMapper):
-                return (
-                    self.max_log_likelihood_fit.inversion.brightest_pixel_centre_list[0]
+                inversion = self.max_log_likelihood_fit.inversion
+                mapper = inversion.cls_list_from(cls=aa.AbstractMapper)[0]
+
+                mapper_valued = aa.MapperValued(
+                    values=inversion.reconstruction_dict[mapper],
+                    mapper=mapper,
                 )
+
+                return mapper_valued.max_pixel_centre
