@@ -1,7 +1,5 @@
 import autoarray as aa
 
-from autolens.lens.to_inversion import TracerToInversion
-
 from autolens.lens.mock.mock_to_inversion import MockTracerToInversion
 
 
@@ -32,7 +30,15 @@ class MockFitImaging(aa.m.MockFitImaging):
         if self._grid is not None:
             return self._grid
 
-        return super().grid
+        return super().grids.lp
+
+    @property
+    def grids(self) -> aa.GridsInterface:
+
+        return aa.GridsInterface(
+            lp=self.grid,
+            pixelization=self.grid,
+        )
 
     @property
     def tracer_to_inversion(self) -> MockTracerToInversion:
