@@ -10,7 +10,6 @@ import autogalaxy as ag
 from autoarray.exc import PixelizationException
 
 from autolens.analysis.analysis.dataset import AnalysisDataset
-from autolens.analysis.preloads import Preloads
 from autolens.imaging.model.result import ResultImaging
 from autolens.imaging.model.visualizer import VisualizerImaging
 from autolens.imaging.fit_imaging import FitImaging
@@ -44,18 +43,14 @@ class AnalysisImaging(AnalysisDataset):
         Parameters
         ----------
         paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization and the pickled objects used by the aggregator output by this function.
         model
-            The PyAutoFit model object, which includes model components representing the galaxies that are fitted to
+            The model object, which includes model components representing the galaxies that are fitted to
             the imaging data.
         """
         super().modify_before_fit(paths=paths, model=model)
 
-        if not paths.is_complete:
-
-            self.set_preloads(paths=paths, model=model)
-
         return self
 
     def log_likelihood_function(self, instance: af.ModelInstance) -> float:
@@ -127,7 +122,6 @@ class AnalysisImaging(AnalysisDataset):
     def fit_from(
         self,
         instance: af.ModelInstance,
-        preload_overwrite: Optional[Preloads] = None,
         run_time_dict: Optional[Dict] = None,
     ) -> FitImaging:
         """
@@ -141,8 +135,6 @@ class AnalysisImaging(AnalysisDataset):
         instance
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
-        preload_overwrite
-            If a `Preload` object is input this is used instead of the preloads stored as an attribute in the analysis.
         check_positions
             Whether the multiple image positions of the lensed source should be checked, i.e. whether they trace
             within the position threshold of one another in the source plane.
@@ -163,41 +155,36 @@ class AnalysisImaging(AnalysisDataset):
 
         adapt_images = self.adapt_images_via_instance_from(instance=instance)
 
-        preloads = preload_overwrite or self.preloads
-
         return FitImaging(
             dataset=self.dataset,
             tracer=tracer,
             dataset_model=dataset_model,
             adapt_images=adapt_images,
             settings_inversion=self.settings_inversion,
-            preloads=preloads,
             run_time_dict=run_time_dict,
         )
 
     def save_attributes(self, paths: af.DirectoryPaths):
         """
-        Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `pickles`
+        Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `files`
         folder such that they can be loaded after the analysis using PyAutoFit's database and aggregator tools.
 
-        For this analysis, it uses the `AnalysisDataset` object's method to output the following:
 
-        - The dataset's data.
-        - The dataset's noise-map.
-        - The settings associated with the dataset.
-        - The settings associated with the inversion.
-        - The settings associated with the pixelization.
-        - The Cosmology.
-        - The adapt image's model image and galaxy images, if used.
+         For this analysis, it uses the `AnalysisDataset` object's method to output the following:
 
-        This function also outputs attributes specific to an imaging dataset:
+         - The settings associated with the inversion.
+         - The settings associated with the pixelization.
+         - The Cosmology.
+         - The adapt image's model image and galaxy images, as `adapt_images.fits`, if used.
+
+        This function also outputs attributes specific to lens modeling:
 
-        - Its PSF.
-        - Its mask.
         - The positions of the brightest pixels in the lensed source which are used to discard mass models.
-        - The preloaded image-plane source plane pixelization if used by the analysis. This ensures that differences in
-          the scikit-learn library do not lead to different pixelizations being computed if results are transferred from
-          a HPC to laptop.
+
+        The following .fits files are also output via the plotter interface:
+
+        - The mask applied to the dataset, in the `PrimaryHDU` of `dataset.fits`.
+        - The imaging dataset as `dataset.fits` (data / noise-map / psf / over sampler / etc.).
 
         It is common for these attributes to be loaded by many of the template aggregator functions given in the
         `aggregator` modules. For example, when using the database tools to perform a fit, the default behaviour is for
@@ -207,7 +194,7 @@ class AnalysisImaging(AnalysisDataset):
         Parameters
         ----------
         paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization, and the pickled objects used by the aggregator output by this function.
         """
         super().save_attributes(paths=paths)
@@ -238,7 +225,7 @@ class AnalysisImaging(AnalysisDataset):
         An `info_dict` is also created which stores information on aspects of the model and dataset that dictate
         run times, so the profiled times can be interpreted with this context.
 
-        The results of this profiling are then output to hard-disk in the `preloads` folder of the model-fit results,
+        The results of this profiling are then output to hard-disk in the `profiling` folder of the model-fit results,
         which they can be inspected to ensure run-times are as expected.
 
         Parameters
@@ -247,7 +234,7 @@ class AnalysisImaging(AnalysisDataset):
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
         paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization and the pickled objects used by the aggregator output by this function.
 
         Returns
