@@ -80,12 +80,11 @@ class FitImagingPlotter(Plotter):
         Returns an `TracerPlotter` corresponding to the `Tracer` in the `FitImaging`.
         """
 
-        extent = self.fit.data.extent_of_zoomed_array(buffer=0)
-        shape_native = self.fit.data.zoomed_around_mask(buffer=0).shape_native
+        zoom = aa.Zoom2D(mask=self.fit.mask)
 
         grid = aa.Grid2D.from_extent(
-            extent=extent,
-            shape_native=shape_native
+            extent=zoom.extent_from(buffer=0),
+            shape_native=zoom.shape_native
         )
 
         return TracerPlotter(
@@ -148,9 +147,12 @@ class FitImagingPlotter(Plotter):
         subtracted_image: bool = False,
         model_image: bool = False,
         plane_image: bool = False,
+        plane_noise_map: bool = False,
+        plane_signal_to_noise_map: bool = False,
         use_source_vmax: bool = False,
         zoom_to_brightest: bool = True,
         interpolate_to_uniform: bool = False,
+        remove_critical_caustic : bool = True
     ):
         """
         Plots images representing each individual `Plane` in the fit's `Tracer` in 2D, which are computed via the
@@ -177,6 +179,14 @@ class FitImagingPlotter(Plotter):
             Whether to make a 2D plot (via `imshow`) of the image of a plane in its source-plane (e.g. unlensed).
             Depending on how the fit is performed, this could either be an image of light profiles of the reconstruction
             of an `Inversion`.
+        plane_noise_map
+            Whether to make a 2D plot of the noise-map of a plane in its source-plane, where the
+            noise map can only be computed when a pixelized source reconstruction is performed and they correspond to
+            the noise map in each reconstructed pixel as given by the inverse curvature matrix.
+        plane_signal_to_noise_map
+            Whether to make a 2D plot of the signal-to-noise map of a plane in its source-plane,
+            where the signal-to-noise map values can only be computed when a pixelized source reconstruction and they
+            are the ratio of reconstructed flux to error in each pixel.
         use_source_vmax
             If `True`, the maximum value of the lensed source (e.g. in the image-plane) is used to set the `vmax` of
             certain plots (e.g. the `data`) in order to ensure the lensed source is visible compared to the lens.
@@ -186,15 +196,20 @@ class FitImagingPlotter(Plotter):
         interpolate_to_uniform
             If `True`, the mapper's reconstruction is interpolated to a uniform grid before plotting, for example
             meaning that an irregular Delaunay grid can be plotted as a uniform grid.
+        remove_critical_caustic
+            Whether to remove critical curves and caustics from the plot.
         """
 
         visuals_2d = self.get_visuals_2d()
 
         visuals_2d_no_critical_caustic = self.get_visuals_2d()
-        visuals_2d_no_critical_caustic.tangential_critical_curves = None
-        visuals_2d_no_critical_caustic.radial_critical_curves = None
-        visuals_2d_no_critical_caustic.tangential_caustics = None
-        visuals_2d_no_critical_caustic.radial_caustics = None
+
+        if remove_critical_caustic:
+
+            visuals_2d_no_critical_caustic.tangential_critical_curves = None
+            visuals_2d_no_critical_caustic.radial_critical_curves = None
+            visuals_2d_no_critical_caustic.tangential_caustics = None
+            visuals_2d_no_critical_caustic.radial_caustics = None
 
         plane_indexes = self.plane_indexes_from(plane_index=plane_index)
 
@@ -288,8 +303,41 @@ class FitImagingPlotter(Plotter):
                         interpolate_to_uniform=interpolate_to_uniform
                     )
 
-        if use_source_vmax:
-            self.mat_plot_2d.cmap.kwargs.pop("vmax")
+            if use_source_vmax:
+                try:
+                    self.mat_plot_2d.cmap.kwargs.pop("vmax")
+                except KeyError:
+                    pass
+
+            if plane_noise_map:
+
+                if self.tracer.planes[plane_index].has(cls=aa.Pixelization):
+
+                    inversion_plotter = self.inversion_plotter_of_plane(
+                        plane_index=plane_index
+                    )
+
+                    inversion_plotter.figures_2d_of_pixelization(
+                        pixelization_index=0,
+                        reconstruction_noise_map=True,
+                        zoom_to_brightest=zoom_to_brightest,
+                        interpolate_to_uniform=interpolate_to_uniform
+                    )
+
+            if plane_signal_to_noise_map:
+
+                if self.tracer.planes[plane_index].has(cls=aa.Pixelization):
+
+                    inversion_plotter = self.inversion_plotter_of_plane(
+                        plane_index=plane_index
+                    )
+
+                    inversion_plotter.figures_2d_of_pixelization(
+                        pixelization_index=0,
+                        signal_to_noise_map=True,
+                        zoom_to_brightest=zoom_to_brightest,
+                        interpolate_to_uniform=interpolate_to_uniform
+                    )
 
     def subplot_of_planes(self, plane_index: Optional[int] = None):
         """
@@ -374,7 +422,7 @@ class FitImagingPlotter(Plotter):
             auto_labels=AutoLabels(filename=auto_filename),
         )
 
-    def subplot_fit(self):
+    def subplot_fit(self, plane_index: Optional[int] = None):
         """
         Standard subplot of the attributes of the plotter's `FitImaging` object.
         """
@@ -396,21 +444,22 @@ class FitImagingPlotter(Plotter):
         # If the lens light is not included the subplot index does not increase, so we must manually set it to 4
         self.mat_plot_2d.subplot_index = 6
 
-        final_plane_index = len(self.fit.tracer.planes) - 1
+        plane_index_tag = "" if plane_index is None else f"_{plane_index}"
+
+        plane_index = len(self.fit.tracer.planes) - 1 if plane_index is None else plane_index
 
         self.mat_plot_2d.cmap.kwargs["vmin"] = 0.0
 
         self.set_title(label="Lens Light Subtracted Image")
-        self.figures_2d_of_planes(plane_index=final_plane_index, subtracted_image=True, use_source_vmax=True)
+        self.figures_2d_of_planes(plane_index=plane_index, subtracted_image=True, use_source_vmax=True)
 
         self.set_title(label="Source Model Image (Image Plane)")
-        self.figures_2d_of_planes(plane_index=final_plane_index, model_image=True, use_source_vmax=True)
+        self.figures_2d_of_planes(plane_index=plane_index, model_image=True, use_source_vmax=True)
 
         self.mat_plot_2d.cmap.kwargs.pop("vmin")
 
         self.set_title(label="Source Plane (Zoomed)")
-        self.figures_2d_of_planes(plane_index=final_plane_index, plane_image=True, use_source_vmax=True)
-
+        self.figures_2d_of_planes(plane_index=plane_index, plane_image=True, use_source_vmax=True)
 
         self.set_title(label=None)
 
@@ -432,7 +481,7 @@ class FitImagingPlotter(Plotter):
 
         self.set_title(label="Source Plane (No Zoom)")
         self.figures_2d_of_planes(
-            plane_index=final_plane_index,
+            plane_index=plane_index,
             plane_image=True,
             zoom_to_brightest=False,
             use_source_vmax=True
@@ -441,11 +490,11 @@ class FitImagingPlotter(Plotter):
         self.set_title(label=None)
 
         self.mat_plot_2d.output.subplot_to_figure(
-            auto_filename="subplot_fit"
+            auto_filename=f"subplot_fit{plane_index_tag}"
         )
         self.close_subplot_figure()
 
-    def subplot_fit_log10(self):
+    def subplot_fit_log10(self, plane_index: Optional[int] = None):
         """
         Standard subplot of the attributes of the plotter's `FitImaging` object.
         """
@@ -482,21 +531,22 @@ class FitImagingPlotter(Plotter):
         # If the lens light is not included the subplot index does not increase, so we must manually set it to 4
         self.mat_plot_2d.subplot_index = 6
 
-        final_plane_index = len(self.fit.tracer.planes) - 1
+        plane_index_tag = "" if plane_index is None else f"_{plane_index}"
+
+        plane_index = len(self.fit.tracer.planes) - 1 if plane_index is None else plane_index
 
         self.mat_plot_2d.cmap.kwargs["vmin"] = 0.0
 
         self.set_title(label="Lens Light Subtracted Image")
-        self.figures_2d_of_planes(plane_index=final_plane_index, subtracted_image=True, use_source_vmax=True)
+        self.figures_2d_of_planes(plane_index=plane_index, subtracted_image=True, use_source_vmax=True)
 
         self.set_title(label="Source Model Image (Image Plane)")
-        self.figures_2d_of_planes(plane_index=final_plane_index, model_image=True, use_source_vmax=True)
+        self.figures_2d_of_planes(plane_index=plane_index, model_image=True, use_source_vmax=True)
 
         self.mat_plot_2d.cmap.kwargs.pop("vmin")
 
         self.set_title(label="Source Plane (Zoomed)")
-        self.figures_2d_of_planes(plane_index=final_plane_index, plane_image=True, use_source_vmax=True)
-
+        self.figures_2d_of_planes(plane_index=plane_index, plane_image=True, use_source_vmax=True)
 
         self.set_title(label=None)
 
@@ -522,7 +572,7 @@ class FitImagingPlotter(Plotter):
 
         self.set_title(label="Source Plane (No Zoom)")
         self.figures_2d_of_planes(
-            plane_index=final_plane_index,
+            plane_index=plane_index,
             plane_image=True,
             zoom_to_brightest=False,
             use_source_vmax=True
@@ -531,7 +581,7 @@ class FitImagingPlotter(Plotter):
         self.set_title(label=None)
 
         self.mat_plot_2d.output.subplot_to_figure(
-            auto_filename="subplot_fit_log10"
+            auto_filename=f"subplot_fit_log10{plane_index_tag}"
         )
         self.close_subplot_figure()
 
@@ -588,68 +638,76 @@ class FitImagingPlotter(Plotter):
 
     def subplot_mappings_of_plane(self, plane_index: Optional[int] = None, auto_filename: str = "subplot_mappings"):
 
-        if not self.fit.inversion.has(cls=aa.Pixelization):
-            return
+        try:
 
-        plane_indexes = self.plane_indexes_from(plane_index=plane_index)
+            plane_indexes = self.plane_indexes_from(plane_index=plane_index)
 
-        for plane_index in plane_indexes:
-            
-            pixelization_index = 0
+            for plane_index in plane_indexes:
 
-            inversion_plotter = self.inversion_plotter_of_plane(plane_index=0)
+                pixelization_index = 0
 
-            inversion_plotter.open_subplot_figure(number_subplots=4)
+                inversion_plotter = self.inversion_plotter_of_plane(plane_index=0)
 
-            inversion_plotter.figures_2d_of_pixelization(
-                pixelization_index=pixelization_index, data_subtracted=True
-            )
+                inversion_plotter.open_subplot_figure(number_subplots=4)
 
-            total_pixels = conf.instance["visualize"]["general"]["inversion"][
-                "total_mappings_pixels"
-            ]
+                inversion_plotter.figures_2d_of_pixelization(
+                    pixelization_index=pixelization_index, data_subtracted=True
+                )
 
-            pix_indexes = inversion_plotter.inversion.brightest_pixel_list_from(
-                total_pixels=total_pixels, filter_neighbors=True
-            )
+                total_pixels = conf.instance["visualize"]["general"]["inversion"][
+                    "total_mappings_pixels"
+                ]
 
-            inversion_plotter.visuals_2d.pix_indexes = [
-                [index] for index in pix_indexes[pixelization_index]
-            ]
+                mapper = inversion_plotter.inversion.cls_list_from(cls=aa.AbstractMapper)[0]
+                mapper_valued = aa.MapperValued(
+                    values=inversion_plotter.inversion.reconstruction_dict[mapper],
+                    mapper=mapper,
+                )
+                pix_indexes = mapper_valued.max_pixel_list_from(
+                    total_pixels=total_pixels, filter_neighbors=True
+                )
 
-            inversion_plotter.visuals_2d.tangential_critical_curves = None
-            inversion_plotter.visuals_2d.radial_critical_curves = None
+                inversion_plotter.visuals_2d.pix_indexes = [
+                    [index] for index in pix_indexes[pixelization_index]
+                ]
 
-            inversion_plotter.figures_2d_of_pixelization(
-                pixelization_index=pixelization_index, reconstructed_image=True
-            )
+                inversion_plotter.visuals_2d.tangential_critical_curves = None
+                inversion_plotter.visuals_2d.radial_critical_curves = None
 
-            self.visuals_2d.pix_indexes = [
-                [index] for index in pix_indexes[pixelization_index]
-            ]
+                inversion_plotter.figures_2d_of_pixelization(
+                    pixelization_index=pixelization_index, reconstructed_image=True
+                )
 
-            self.figures_2d_of_planes(
-                plane_index=plane_index,
-                plane_image=True,
-                use_source_vmax=True
-            )
+                self.visuals_2d.pix_indexes = [
+                    [index] for index in pix_indexes[pixelization_index]
+                ]
 
-            self.set_title(label="Source Reconstruction (Unzoomed)")
-            self.figures_2d_of_planes(
-                plane_index=plane_index,
-                plane_image=True,
-                zoom_to_brightest=False,
-                use_source_vmax=True
-            )
-            self.set_title(label=None)
+                self.figures_2d_of_planes(
+                    plane_index=plane_index,
+                    plane_image=True,
+                    use_source_vmax=True
+                )
 
-            self.visuals_2d.pix_indexes = None
+                self.set_title(label="Source Reconstruction (Unzoomed)")
+                self.figures_2d_of_planes(
+                    plane_index=plane_index,
+                    plane_image=True,
+                    zoom_to_brightest=False,
+                    use_source_vmax=True
+                )
+                self.set_title(label=None)
 
-            inversion_plotter.mat_plot_2d.output.subplot_to_figure(
-                auto_filename=f"{auto_filename}_{pixelization_index}"
-            )
+                self.visuals_2d.pix_indexes = None
 
-            inversion_plotter.close_subplot_figure()
+                inversion_plotter.mat_plot_2d.output.subplot_to_figure(
+                    auto_filename=f"{auto_filename}_{pixelization_index}"
+                )
+
+                inversion_plotter.close_subplot_figure()
+
+        except (IndexError, AttributeError, ValueError):
+
+            pass
 
     def figures_2d(
         self,
