@@ -8,7 +8,6 @@ import autogalaxy as ag
 
 from autogalaxy.abstract_fit import AbstractFitInversion
 
-from autolens.analysis.preloads import Preloads
 from autolens.lens.tracer import Tracer
 from autolens.lens.to_inversion import TracerToInversion
 
@@ -21,7 +20,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         dataset_model: Optional[aa.DatasetModel] = None,
         adapt_images: Optional[ag.AdaptImages] = None,
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
-        preloads: Preloads = Preloads(),
         run_time_dict: Optional[Dict] = None,
     ):
         """
@@ -47,7 +45,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
            algebra solution, is computed).
 
         When performing a model-fit` via ` AnalysisInterferometer` object the `figure_of_merit` of
-        this `FitInterferometer` object is called and returned in the `log_likelihood_function`.
+        this object is called and returned in the `log_likelihood_function`.
 
         Parameters
         ----------
@@ -62,9 +60,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
             reconstructed galaxy's morphology.
         settings_inversion
             Settings controlling how an inversion is fitted for example which linear algebra formalism is used.
-        preloads
-            Contains preloaded calculations (e.g. linear algebra matrices) which can skip certain calculations in
-            the fit.
         run_time_dict
             A dictionary which if passed to the fit records how long function calls which have the `profile_func`
             decorator take to run.
@@ -81,8 +76,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
 
         self.settings_inversion = settings_inversion
 
-        self.preloads = preloads
-
         self.run_time_dict = run_time_dict
 
         super().__init__(
@@ -99,7 +92,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         transform to the sum of light profile images.
         """
         return self.tracer.visibilities_from(
-            grid=self.grid, transformer=self.dataset.transformer
+            grid=self.grids.lp, transformer=self.dataset.transformer
         )
 
     @property
@@ -115,11 +108,9 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         dataset = aa.DatasetInterface(
             data=self.profile_subtracted_visibilities,
             noise_map=self.noise_map,
+            grids=self.grids,
             transformer=self.dataset.transformer,
             w_tilde=self.w_tilde,
-            grid=self.grid,
-            grid_pixelization=self.grid_pixelization,
-            border_relocator=self.dataset.border_relocator,
         )
 
         return TracerToInversion(
@@ -127,7 +118,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
             tracer=self.tracer,
             adapt_images=self.adapt_images,
             settings_inversion=self.settings_inversion,
-            preloads=self.preloads,
         )
 
     @cached_property
@@ -173,7 +163,9 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         For modeling, this dictionary is used to set up the `adapt_images` that adapt certain pixelizations to the
         data being fitted.
         """
-        galaxy_model_image_dict = self.tracer.galaxy_image_2d_dict_from(grid=self.grid)
+        galaxy_model_image_dict = self.tracer.galaxy_image_2d_dict_from(
+            grid=self.grids.lp
+        )
 
         galaxy_linear_obj_image_dict = self.galaxy_linear_obj_data_dict_from(
             use_image=True
@@ -194,7 +186,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
           are solved for first via the inversion.
         """
         galaxy_model_visibilities_dict = self.tracer.galaxy_visibilities_dict_from(
-            grid=self.grid, transformer=self.dataset.transformer
+            grid=self.grids.lp, transformer=self.dataset.transformer
         )
 
         galaxy_linear_obj_visibilities_dict = self.galaxy_linear_obj_data_dict_from(
@@ -242,44 +234,3 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         or `GalaxyPlotter` objects.
         """
         return self.model_obj_linear_light_profiles_to_light_profiles
-
-    def refit_with_new_preloads(
-        self,
-        preloads: Preloads,
-        settings_inversion: Optional[aa.SettingsInversion] = None,
-    ) -> "FitInterferometer":
-        """
-        Returns a new fit which uses the dataset, tracer and other objects of this fit, but uses a different set of
-        preloads input into this function.
-
-        This is used when setting up the preloads objects, to concisely test how using different preloads objects
-        changes the attributes of the fit.
-
-        Parameters
-        ----------
-        preloads
-            The new preloads which are used to refit the data using the
-        settings_inversion
-            Settings controlling how an inversion is fitted for example which linear algebra formalism is used.
-
-        Returns
-        -------
-        A new fit which has used new preloads input into this function but the same dataset, tracer and other settings.
-        """
-        if self.run_time_dict is not None:
-            run_time_dict = {}
-        else:
-            run_time_dict = None
-
-        if settings_inversion is None:
-            settings_inversion = self.settings_inversion
-
-        return FitInterferometer(
-            dataset=self.dataset,
-            tracer=self.tracer,
-            dataset_model=self.dataset_model,
-            adapt_images=self.adapt_images,
-            settings_inversion=settings_inversion,
-            preloads=preloads,
-            run_time_dict=run_time_dict,
-        )
