@@ -21,14 +21,16 @@ class VisualizerInterferometer(af.Visualizer):
         Parameters
         ----------
         paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization and the pickled objects used by the aggregator output by this function.
         model
-            The PyAutoFit model object, which includes model components representing the galaxies that are fitted to
+            The model object, which includes model components representing the galaxies that are fitted to
             the imaging data.
         """
 
-        plotter_interface = PlotterInterfaceInterferometer(image_path=paths.image_path)
+        plotter_interface = PlotterInterfaceInterferometer(
+            image_path=paths.image_path, title_prefix=analysis.title_prefix
+        )
 
         plotter_interface.interferometer(dataset=analysis.interferometer)
 
@@ -71,14 +73,11 @@ class VisualizerInterferometer(af.Visualizer):
         Parameters
         ----------
         paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization, and the pickled objects used by the aggregator output by this function.
         instance
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
-        during_analysis
-            If True the visualization is being performed midway through the non-linear search before it is finished,
-            which may change which images are output.
         """
         fit = analysis.fit_from(instance=instance)
 
@@ -93,11 +92,13 @@ class VisualizerInterferometer(af.Visualizer):
             except exc.InversionException:
                 return
 
-        plotter_interface = PlotterInterfaceInterferometer(image_path=paths.image_path)
+        plotter_interface = PlotterInterfaceInterferometer(
+            image_path=paths.image_path, title_prefix=analysis.title_prefix
+        )
 
         try:
             plotter_interface.fit_interferometer(
-                fit=fit, during_analysis=during_analysis
+                fit=fit,
             )
         except exc.InversionException:
             pass
@@ -105,15 +106,17 @@ class VisualizerInterferometer(af.Visualizer):
         tracer = fit.tracer_linear_light_profiles_to_light_profiles
 
         plotter_interface.tracer(
-            tracer=tracer, grid=fit.grid, during_analysis=during_analysis
+            tracer=tracer,
+            grid=fit.grids.lp,
         )
         plotter_interface.galaxies(
-            galaxies=tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
+            galaxies=tracer.galaxies,
+            grid=fit.grids.lp,
         )
         if fit.inversion is not None:
             try:
                 plotter_interface.inversion(
-                    inversion=fit.inversion, during_analysis=during_analysis
+                    inversion=fit.inversion,
                 )
             except IndexError:
                 pass
