@@ -14,70 +14,6 @@ from autogalaxy.profiles.light.snr import LightProfileSNR
 from autolens.lens import tracer_util
 
 
-def over_sample(func):
-    """
-    Homogenize the inputs and outputs of functions that take 1D or 2D grids of coordinates and return a 1D ndarray
-    which is converted to an `Array2D`, `ArrayIrregular` or `Array1D` object.
-
-    Parameters
-    ----------
-    func
-        A function which computes a set of values from a 1D or 2D grid of coordinates.
-
-    Returns
-    -------
-        A function that has its outputs homogenized to `Array2D`, `ArrayIrregular` or `Array1D` objects.
-    """
-
-    @wraps(func)
-    def wrapper(
-        obj: object,
-        grid: Union[np.ndarray, aa.Grid2D, aa.Grid2DIrregular],
-        *args,
-        **kwargs,
-    ) -> Union[np.ndarray, aa.Array2D, aa.ArrayIrregular, List]:
-        """
-
-        Parameters
-        ----------
-        obj
-            An object whose function uses grid_like inputs to compute quantities at every coordinate on the grid.
-        grid
-            A grid_like object of coordinates on which the function values are evaluated.
-
-        Returns
-        -------
-            The function values evaluated on the grid with the same structure as the input grid_like object.
-        """
-
-        grid_input = grid
-
-        if isinstance(grid, aa.Grid2D):
-            if isinstance(grid.over_sampling, aa.OverSamplingUniform):
-                grid_input = grid.over_sampler.over_sampled_grid
-                grid_input.over_sampling = None
-
-        result = func(obj, grid_input, *args, **kwargs)
-
-        if isinstance(grid, aa.Grid2D):
-            if isinstance(grid.over_sampling, aa.OverSamplingUniform):
-                if isinstance(result, list):
-                    return [
-                        grid.over_sampler.binned_array_2d_from(array=result_i)
-                        for result_i in result
-                    ]
-                elif isinstance(result, dict):
-                    return {
-                        key: grid.over_sampler.binned_array_2d_from(array=result_i)
-                        for key, result_i in result.items()
-                    }
-                return grid.over_sampler.binned_array_2d_from(array=result)
-
-        return result
-
-    return wrapper
-
-
 class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
     def __init__(
         self,
@@ -167,7 +103,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         )
 
     @property
-    def planes(self):
+    def planes(self) -> List[ag.Galaxies]:
         """
         Returns a list of list of galaxies grouped into their planes, where planes contained all galaxies at the same
         unique redshift.
@@ -327,13 +263,37 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             planes.
         """
 
-        return tracer_util.traced_grid_2d_list_from(
+        grid_2d_list = tracer_util.traced_grid_2d_list_from(
             planes=self.planes,
             grid=grid,
             cosmology=self.cosmology,
             plane_index_limit=plane_index_limit,
         )
 
+        if isinstance(grid, aa.Grid2D):
+            grid_2d_over_sampled_list = tracer_util.traced_grid_2d_list_from(
+                planes=self.planes,
+                grid=grid.over_sampled,
+                cosmology=self.cosmology,
+                plane_index_limit=plane_index_limit,
+            )
+
+            grid_2d_new_list = []
+
+            for i in range(len(grid_2d_list)):
+                grid_2d_new = aa.Grid2D(
+                    values=grid_2d_list[i],
+                    mask=grid.mask,
+                    over_sampled=grid_2d_over_sampled_list[i],
+                    over_sample_size=grid.over_sample_size,
+                )
+
+                grid_2d_new_list.append(grid_2d_new)
+
+            return grid_2d_new_list
+
+        return grid_2d_list
+
     def grid_2d_at_redshift_from(
         self, grid: aa.type.Grid2DLike, redshift: float
     ) -> aa.type.Grid2DLike:
@@ -399,14 +359,15 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         """
         return max(
             [
-                plane_index
-                if any([galaxy.has(cls=ag.LightProfile) for galaxy in galaxies])
-                else 0
+                (
+                    plane_index
+                    if any([galaxy.has(cls=ag.LightProfile) for galaxy in galaxies])
+                    else 0
+                )
                 for (plane_index, galaxies) in enumerate(self.planes)
             ]
         )
 
-    @over_sample
     def image_2d_list_from(
         self,
         grid: aa.type.Grid2DLike,
@@ -454,12 +415,6 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             therefore is used to pass the `operated_only` input to these methods.
         """
 
-        if hasattr(grid, "over_sampling"):
-            if isinstance(grid.over_sampling, aa.OverSamplingIterate):
-                return self.image_2d_list_over_sampled_from(
-                    grid=grid, operated_only=operated_only
-                )
-
         traced_grid_list = self.traced_grid_2d_list_from(
             grid=grid, plane_index_limit=self.upper_plane_index_with_light_profile
         )
@@ -469,18 +424,18 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         for plane_index in range(len(traced_grid_list)):
             galaxies = self.planes[plane_index]
 
-            image_2d_list.append(
-                sum(
-                    [
-                        galaxy.image_2d_from(
-                            grid=traced_grid_list[plane_index],
-                            operated_only=operated_only,
-                        )
-                        for galaxy in galaxies
-                    ]
-                )
+            image_2d = sum(
+                [
+                    galaxy.image_2d_from(
+                        grid=traced_grid_list[plane_index],
+                        operated_only=operated_only,
+                    )
+                    for galaxy in galaxies
+                ]
             )
 
+            image_2d_list.append(image_2d)
+
         if self.upper_plane_index_with_light_profile < self.total_planes - 1:
             if isinstance(grid, aa.Grid2D):
                 image_2d = aa.Array2D(
@@ -496,145 +451,6 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
 
         return image_2d_list
 
-    @over_sample
-    def image_2d_of_plane_from(
-        self,
-        grid: aa.type.Grid2DLike,
-        plane_index: int,
-        operated_only: Optional[bool] = None,
-    ) -> aa.Array2D:
-        """
-        Returns a 2D image of an input plane from a 2D grid of Cartesian (y,x) coordinates.
-
-        The image of the plane is computed by ray-tracing the grid using te mass profiles of all galaxies before the
-        input plane and then summing the images of all galaxies in that plane. If a plane has no galaxies, or if the
-        galaxies in a plane, has no light profiles, a numpy array of zeros is returned.
-
-        For example, if the tracer's planes contain galaxies at redshifts z=0.5, z=1.0 and z=2.0, and the galaxies
-        at redshifts z=0.5 and z=1.0 have light and mass profiles, the returned image for `plane_index=1` will be the
-        image of the galaxy at z=1.0, where the image at redshift z=1.0 will include the lensing effects of the
-        galaxies at z=0.5. The image at redshift z=2.0 will be ignored.
-
-        The `plane_index` input specifies which plane the image os returned for. This calculation saves computational
-        time compared to `image_2d_list_from` when only the image of a specific plane is needed. It is also used to
-        perform iterative over-sampling calculations.
-
-        The images output by this function do not include instrument operations, such as PSF convolution (for imaging
-        data) or a Fourier transform (for interferometer data).
-
-        Inherited methods in the `autogalaxy.operate.image` package can apply these operations to the images.
-        These functions may have the `operated_only` input passed to them, which is why this function includes
-        the `operated_only` input.
-
-        If the `operated_only` input is included, the function omits light profiles which are parents of
-        the `LightProfileOperated` object, which signifies that the light profile represents emission that has
-        already had the instrument operations (e.g. PSF convolution, a Fourier transform) applied to it and therefore
-        that operation is not performed again.
-
-        See the `autogalaxy.profiles.light` package for details of how images are computed from a light
-        profile.
-
-        Parameters
-        ----------
-        grid
-            The 2D (y, x) coordinates where values of the image are evaluated.
-        plane_index
-            The plane index of the plane the image is computed.
-        operated_only
-            The returned list from this function contains all light profile images, and they are never operated on
-            (e.g. via the imaging PSF). However, inherited methods in the `autogalaxy.operate.image` package can
-            apply these operations to the images, which may have the `operated_only` input passed to them. This input
-            therefore is used to pass the `operated_only` input to these methods.
-        """
-
-        if not self.planes[plane_index].has(cls=ag.LightProfile):
-            if isinstance(grid, aa.Grid2D):
-                return aa.Array2D(values=np.zeros(shape=grid.shape[0]), mask=grid.mask)
-            else:
-                return aa.ArrayIrregular(values=np.zeros(grid.shape[0]))
-
-        traced_grid_list = self.traced_grid_2d_list_from(
-            grid=grid, plane_index_limit=plane_index
-        )
-
-        return sum(
-            [
-                galaxy.image_2d_from(
-                    grid=traced_grid_list[plane_index],
-                    operated_only=operated_only,
-                )
-                for galaxy in self.planes[plane_index]
-            ]
-        )
-
-    def image_2d_list_over_sampled_from(
-        self,
-        grid: aa.type.Grid2DLike,
-        operated_only: Optional[bool] = None,
-    ) -> List[aa.Array2D]:
-        """
-        Returns a list of the 2D images for each plane from a 2D grid of Cartesian (y,x) coordinates where adaptive
-        and iterative over-sampling is used to compute the image.
-
-        The image of each plane is computed by iteratively ray-tracing the grid using the mass profiles of each
-        galaxies and then summing the images of all galaxies in that plane, until a threshold level of accuracy
-        defined by the over-sampling grid is met. If a plane has no galaxies, or if the galaxies in a plane
-        has no light profiles, a numpy array of zeros is returned.
-
-        For example, if the tracer's planes contain galaxies at redshifts z=0.5, z=1.0 and z=2.0, and the galaxies
-        at redshifts z=0.5 and z=1.0 have light and mass profiles, the returned list of images will be the image of the
-        galaxies at z=0.5 and z=1.0, where the image at redshift z=1.0 will include the lensing effects of the galaxies
-        at z=0.5. The image at redshift z=2.0 will be a numpy array of zeros.
-
-        The implementation of this function has to wrap a function in the iterative over sampler which performs the
-        iterative over-sampling calculation. This requires a function to be defined internally in this function
-        which meets the requirements of the over-sample.
-
-        The images output by this function do not include instrument operations, such as PSF convolution (for imaging
-        data) or a Fourier transform (for interferometer data).
-
-        Inherited methods in the `autogalaxy.operate.image` package can apply these operations to the images.
-        These functions may have the `operated_only` input passed to them, which is why this function includes
-        the `operated_only` input.
-
-        If the `operated_only` input is included, the function omits light profiles which are parents of
-        the `LightProfileOperated` object, which signifies that the light profile represents emission that has
-        already had the instrument operations (e.g. PSF convolution, a Fourier transform) applied to it and therefore
-        that operation is not performed again.
-
-        See the `autogalaxy.profiles.light` package for details of how images are computed from a light
-        profile.
-
-        Parameters
-        ----------
-        grid
-            The 2D (y, x) coordinates where values of the image are evaluated, which has an iterative over-sampling
-            applied to it.
-        operated_only
-            The returned list from this function contains all light profile images, and they are never operated on
-            (e.g. via the imaging PSF). However, inherited methods in the `autogalaxy.operate.image` package can
-            apply these operations to the images, which may have the `operated_only` input passed to them. This input
-            therefore is used to pass the `operated_only` input to these methods.
-        """
-
-        image_2d_list = []
-
-        for plane_index in range(len(self.planes)):
-
-            def func(obj, grid, *args, **kwargs):
-                return self.image_2d_of_plane_from(
-                    grid=grid,
-                    operated_only=operated_only,
-                    plane_index=plane_index,
-                )
-
-            image_2d = grid.over_sampler.array_via_func_from(func=func, obj=self)
-
-            image_2d_list.append(image_2d)
-
-        return image_2d_list
-
-    @over_sample
     @aa.grid_dec.to_array
     @aa.profile_func
     def image_2d_from(
@@ -728,27 +544,20 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             pixel_scales=plane_image.pixel_scales,
         )
 
-        grid_input = grid
-
-        if isinstance(grid, aa.Grid2D):
-            if isinstance(grid.over_sampling, aa.OverSamplingUniform):
-                grid_input = grid.over_sampler.over_sampled_grid
-
         traced_grid = self.traced_grid_2d_list_from(
-            grid=grid_input, plane_index_limit=plane_index
+            grid=grid, plane_index_limit=plane_index
         )[plane_index]
 
         image = griddata(
             points=plane_grid,
             values=plane_image,
-            xi=traced_grid,
+            xi=traced_grid.over_sampled,
             fill_value=0.0,
             method="linear",
         )
 
         if isinstance(grid, aa.Grid2D):
-            if isinstance(grid.over_sampling, aa.OverSamplingUniform):
-                image = grid.over_sampler.binned_array_2d_from(array=image)
+            image = grid.over_sampler.binned_array_2d_from(array=image)
 
         if include_other_planes:
             image_list = self.image_2d_list_from(grid=grid, operated_only=False)
@@ -765,7 +574,6 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             mask=grid.mask,
         )
 
-    @over_sample
     def galaxy_image_2d_dict_from(
         self, grid: aa.type.Grid2DLike, operated_only: Optional[bool] = None
     ) -> Dict[ag.Galaxy, np.ndarray]:
@@ -994,7 +802,18 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         return cls_list
 
     @property
-    def plane_indexes_with_pixelizations(self):
+    def plane_indexes_with_pixelizations(self) -> List[int]:
+        """
+        Returns a list of integer indexes of the indexes of planes which use a `Pixelization` to reconstruct the
+        source galaxy.
+
+        This list is used to set up an inversion, whereby each pixelization is extracted from the tracer with its
+        corresponding ray-traced grid and passed to the PyAutoArray `inversion` module.
+
+        Returns
+        -------
+        The list of integer indexes of the planes which use a `Pixelization` to reconstruct the source galaxy.
+        """
         plane_indexes_with_inversions = [
             plane_index if plane.has(cls=aa.Pixelization) else None
             for (plane_index, plane) in enumerate(self.planes)
@@ -1005,6 +824,32 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             if plane_index is not None
         ]
 
+    @property
+    def plane_indexes_with_images(self):
+        """
+        Returns a list of integer indexes of the indexes of planes which create an image, meaning they either
+        have a `LightProfile` or `Pixelization`.
+
+        This list is used to visualize double source plane lenses, whereby a fit for every plane with a
+        `LightProfile` or `Pixelization` is created.
+
+        Returns
+        -------
+        The list of integer indexes of the planes which create an image.
+        """
+        plane_indexes_with_images = [
+            plane_index if plane.has(cls=ag.LightProfile) else None
+            for (plane_index, plane) in enumerate(self.planes)
+        ] + self.plane_indexes_with_pixelizations
+
+        plane_indexes_with_images = list(dict.fromkeys(plane_indexes_with_images))
+
+        return [
+            plane_index
+            for plane_index in plane_indexes_with_images
+            if plane_index is not None
+        ]
+
     @property
     def perform_inversion(self) -> bool:
         """
